from inc_noesis import *

def registerNoesisTypes():
    handle = noesis.register('Captain Blood GMX Model', '.gmx')
    noesis.setHandlerTypeCheck(handle, gmxCheckType)
    noesis.setHandlerLoadModel(handle, gmxLoadModel)
    
    #noesis.logPopup()
    
    return 1
    
def gmxCheckType(data):
    if len(data) < 8:
        return 0
        
    bs = NoeBitStream(data)
    sign = bs.readBytes(4);
    
    if sign == b'MOEG':
        print('Proper Big Endian GMX format.\n')
        
    elif sign == b'GMX ':
        print('Old Little Endian GMX format. Not supported while.\n')
        return 0
        
    elif sign == b'MESH':
        print('Old Little Endian GMX format. Not supported while.\n')
        return 0
        
    else:
        return 0
        
    return 1
    
def gmxLoadModel(data, mdlList):

    if len(data) < 8:
        return 0
        
    bs = NoeBitStream(data)
    sign = bs.readBytes(4);
    
    if sign == b'MOEG':
        print('Proper Big Endian GMX format.\n')
        
    elif sign == b'GMX ':
        print('Old Little Endian GMX format. Not supported while.\n')
        return 0
        
    elif sign == b'MESH':
        print('Old Little Endian GMX format. Not supported while.\n')
        return 0
        
    else:
        return 0
        
    
    ctx = rapi.rpgCreateContext()
    rapi.rpgSetOption(noesis.RPGOPT_BIGENDIAN, 1)
    
    bs.seek(28, NOESEEK_ABS)
    namesBlockSizeAligned = bs.read('>i')[0]
    
    bs.seek(112, NOESEEK_ABS)
    facesOffset = bs.read('>i')[0]
    
    bs.seek(232, NOESEEK_ABS)
    facesBlockSize = bs.read('>i')[0]
    verticesBlockSize = bs.read('>i')[0]
    idsBlockSize = bs.read('>i')[0]
    numFaces = bs.read('>i')[0]
    numVertices = bs.read('>i')[0]
    numIds = bs.read('>i')[0] #bone ids
    facesBlockSizeAligned = bs.read('>i')[0]
    verticesBlockSizeAligned = bs.read('>i')[0]
    idsBlockSizeAligned = bs.read('>i')[0]
    
    bs.seek(820 + facesOffset, NOESEEK_ABS)
    faceBuffer = bs.readBytes(facesBlockSize)
    
    bs.seek(820 + facesOffset + facesBlockSizeAligned, NOESEEK_ABS)
    vertexBuffer = bs.readBytes(verticesBlockSize)
    
    rapi.rpgBindPositionBufferOfs(vertexBuffer, noesis.RPGEODATA_FLOAT, 32, 0) #Vector3 Position
    #rapi.rpgBindNormalBuffer(vertexBuffer, noesis.RPGEODATA_UBYTE, 32, 12) #Packed Normal
    #rapi.rpgBindTangentBuffer(vertexBuffer, noesis.RPGEODATA_UBYTE, 32, 16) #Packed Tangent
    #rapi.rpgBindNormalBufferOfs(vertexBuffer, noesis.RPGEODATA_UBYTE, 32, 20) #Packed Binormal
    rapi.rpgBindUV1BufferOfs(vertexBuffer, noesis.RPGEODATA_USHORT, 32, 24) #Packed UV
    #rapi.rpgBindBoneWeightBuffer(vertexBuffer, noesis.RPGEODATA_UBYTE, 32, 28) #Packed Normal
    
    rapi.rpgCommitTriangles(faceBuffer, noesis.RPGEODATA_SHORT, numFaces, noesis.RPGEO_TRIANGLE, 1)
    
    mdl = rapi.rpgConstructModel()
    mdlList.append(mdl)
    rapi.rpgClearBufferBinds()
    
    return 1
        